==> 0.0.61.tar.gz: lib/src/custom_components/custom_table/TableRowIcon/view.dart <==

import 'package:flutter/material.dart';
import 'package:nirrti/src/custom_components/custom_table/TableRowIcon/view_model.dart';

mixin ViewMixin {
  render(BuildContext context, TableRowIconState state) {
    return SizedBox(
      width: 40,
      height: 40,
      child: InkWell(
        onTap: () {
          state.widget.callback();
        },
        child: MouseRegion(
          cursor: SystemMouseCursors.click,
          child: state.widget.type == IconType.delete ?
            Icon(
              Icons.delete,
              color: Theme.of(context).colorScheme.error
            )
            : state.widget.type == IconType.edit ?
            Icon(
              Icons.edit,
              color: Theme.of(context).colorScheme.primary
            ) : state.widget.type == IconType.validate ?
            Icon(
              Icons.check,
              color: Theme.of(context).colorScheme.secondary
            ) : state.widget.type == IconType.cog ?
            Icon(
              Icons.settings,
              color: Theme.of(context).colorScheme.surfaceVariant
            ) : state.widget.type == IconType.pay ?
            Icon(
              Icons.payment,
              color: Theme.of(context).colorScheme.surfaceVariant
            ) : state.widget.type == IconType.view ?
            Icon(
              Icons.remove_red_eye,
              color: Theme.of(context).colorScheme.surfaceVariant
            ) : state.widget.type == IconType.cross ?
            Icon(
              Icons.close,
              color: Theme.of(context).colorScheme.error
            ) : state.widget.type == IconType.user ?
            Icon(
              Icons.person,
              color: Theme.of(context).colorScheme.primary
            ) : state.widget.type == IconType.download ?
            Icon(
              Icons.download,
              color: Theme.of(context).colorScheme.primary
            ) : state.widget.type == IconType.note ?
            Icon(
              Icons.note,
              color: Theme.of(context).colorScheme.primary
            ) 
          : Icon(
            Icons.delete,
            color: Theme.of(context).colorScheme.error
          )
        )
      ),
    );
  }
}

==> 0.0.82.tar.gz: lib/src/custom_components/custom_table/TableRowIcon/view.dart <==

import 'package:flutter/material.dart';
import 'package:nirrti/src/custom_components/custom_table/TableRowIcon/view_model.dart';

mixin ViewMixin {
  render(BuildContext context, TableRowIconState state) {
    return SizedBox(
      width: 40,
      height: 40,
      child: InkWell(
        onTap: () {
          state.widget.callback();
        },
        child: MouseRegion(
          cursor: SystemMouseCursors.click,
          child: state.widget.type == IconType.delete ?
            Icon(
              Icons.delete,
              color: Theme.of(context).colorScheme.error
            )
            : state.widget.type == IconType.edit ?
            Icon(
              Icons.edit,
              color: Theme.of(context).colorScheme.primary
            ) : state.widget.type == IconType.validate ?
            Icon(
              Icons.check,
              color: Theme.of(context).colorScheme.secondary
            ) : state.widget.type == IconType.cog ?
            Icon(
              Icons.settings,
              color: Theme.of(context).colorScheme.surfaceContainerHighest
            ) : state.widget.type == IconType.pay ?
            Icon(
              Icons.payment,
              color: Theme.of(context).colorScheme.surfaceContainerHighest
            ) : state.widget.type == IconType.view ?
            Icon(
              Icons.remove_red_eye,
              color: Theme.of(context).colorScheme.surfaceContainerHighest
            ) : state.widget.type == IconType.cross ?
            Icon(
              Icons.close,
              color: Theme.of(context).colorScheme.error
            ) : state.widget.type == IconType.user ?
            Icon(
              Icons.person,
              color: Theme.of(context).colorScheme.primary
            ) : state.widget.type == IconType.download ?
            Icon(
              Icons.download,
              color: Theme.of(context).colorScheme.primary
            ) : state.widget.type == IconType.note ?
            Icon(
              Icons.note,
              color: Theme.of(context).colorScheme.primary
            ) 
          : Icon(
            Icons.delete,
            color: Theme.of(context).colorScheme.error
          )
        )
      ),
    );
  }
}
